/* CPS_AnalysisMain.do file for Participation and Labor Market Policy */
/* Authors: Ben Griffy and Adrian Masters */

cd "$datadir"
use CPSGenSampFinal.dta, replace

drop if statefip==02

drop if statefip==04

drop if statefip==06

drop if statefip==08

drop if statefip==09

drop if statefip==12

drop if statefip==17

drop if statefip==23

drop if statefip==25

drop if statefip==26

drop if statefip==29

drop if statefip==30

drop if statefip==32

drop if statefip==34

drop if statefip==35

drop if statefip==36

drop if statefip==39

drop if statefip==41

drop if statefip==44

drop if statefip==50

drop if statefip==53

sort newid year month

by newid: gen nextempstat = empstat[_n+1] if newid==newid[_n+1]

by newid: gen lastempstat = empstat[_n-1] if newid==newid[_n-1]

by newid: gen foundJob = (empstat==21 & nextempstat==10)

by newid: replace foundJob = . if empstat != 21

estpost summ foundJob

gen hrsWrk = earnweek/hourwage
replace hrsWrk = . if empstat != 10 | hourwage == 0 | earnweek == 0

cd "$modeldatadir"

estout using JFRMoments.csv, replace cells("mean")

* obtaining wahe histogram

duplicates drop newid, force
* drops the duplicates so we have one observation of each observed wage

cd "$modeldatadir"
tabout empstat using empDist.csv, cells(freq col) f(5c) style(csv) replace

tab empstat, matcell(x)

local NILF = x[5,1]/r(N)
local ILF = 1 - `NILF'

di `NILF'

gen nilf = (empstat==34)

gen urate = (empstat==21)
replace urate = . if nilf == 1

estpost summ nilf urate

/* tabout urate nilf using testmoments.csv, cells(freq col) f(5c) style(csv) replace */


cd "$modeldatadir"

estout using ModelEmpMoments.csv, replace cells("mean")

cd "$datadir"
use CPSWorkingSampFinal.dta, replace

* next lines drop states where minwage was above $7.25 in 2014
* AK, AZ, CA, CO, CT, Fl, IL, ME, MA, MI, MO, MT, NV, NJ, NM, NY, OH, OR, RI, VT, WA
*

drop if statefip==02

drop if statefip==04

drop if statefip==06

drop if statefip==08

drop if statefip==09

drop if statefip==12

drop if statefip==17

drop if statefip==23

drop if statefip==25

drop if statefip==26

drop if statefip==29

drop if statefip==30

drop if statefip==32

drop if statefip==34

drop if statefip==35

drop if statefip==36

drop if statefip==39

drop if statefip==41

drop if statefip==44

drop if statefip==50

drop if statefip==53



* obtaining wahe histogram

duplicates drop newid, force
* drops the duplicates so we have one observation of each observed wage

* next two lines generate values of the log-normal density based on calculation from
* matlab file mbln1 use avewage as x axis to get mergable plots
* can also use trial and error to get the distributions close in appearance
* paramters need to be changed using results from Matlab program mbln1
* if the mean of the underlying normal is mu and s.d is sigma formaula should be:
* y2ln=exp(-((ln(avewage)-mu)^2)/(2*sigma^2))/(avewage*sigma*(2*_pi)^(1/2)*adjdis)
* where adjdis is the number taken from Matlab file mbln1 to correct for loss of density
* to the left of truncation point (right tail adjstment is minuscule)

gen lnmwage = log(mwage)

tobit lnmwage, ll

mat b = e(b)

local muP = b[1,1]
local sigP = b[1,2]

gen y2ln=exp(-((ln(mwage)-`muP')^2)/(2*`sigP'^2))/(mwage*`sigP'*(2*_pi)^(1/2)*`ILF')

local modew = exp(`muP'-`sigP'^2)

di `modew'

/* generate y2ln=exp(-((ln(mwage)-2.3269)^2)/(2*0.3601^2))/(mwage*0.3601*(2*_pi)^(1/2)*0.8069) */

* need to sort by mwage so that graph looks ok

sort mwage

 *g rearnwt=round(earnwt)
 * generates rounded version of earnwt as they need integer values for histogram

 *label variable rearnwt "rounded value of earnwt"


* to overlay them use:

twoway (histogram mwage if mwage>=7.50 & mwage<30.5, width(1)) (line y2ln mwage if mwage<30)
* $7.30 is used to take out the spike at the minimum to compare with Matlab output


*graph save hist2
* to obtain the heights of the bars and the bin centers use (more on this command is under: search histogram)
* cut-off limits can be adjusted along with bin width. It creates new gvariables ht and binc. Use these to obtain input
* paramters for the matlab program mbln1. Doesn't create a pictoral histogram just the numbers used to obtain one.

cumul mwage, gen(wageDens) eq

* to get a comaprable distributio of measured wages and those coming from the Matlab ptogram we have to
* creat a new variable, wdisadj, that is scaled up by the amount of density lost to the left of 7.25 then you can run:
*twoway (histogram mwage if mwage>=7.50 & mwage<=30.5, width(1)) (line wplotdis wplotvec if wplotvec>=7.50 & wplotvec<30)

/* twoway (histogram mwage if mwage>=7.50 & mwage<=30.5, width(1)) (line wplotdis wplotvec if wplotvec>=7.50 & wplotvec<30) gen(htPaper2 bincPaper2) */

twoway__histogram_gen mwage if mwage>=7.5 & mwage<30.5 , width(0.25) gen(htPaper bincPaper)

twoway__histogram_gen mwage if mwage>=7.5 & mwage<30.5 , width(0.5) gen(htPaperWide bincPaperWide)

cumul mwage if mwage>=7.25 & mwage<=30.5, gen(wageDens2) eq

cd "$modeldatadir"

tabout bincPaper using wageDens.csv, cell(mean htPaper) f(5c) style(csv) sum replace

tabout bincPaperWide using wageDensWide.csv, cell(mean htPaperWide) f(5c) style(csv) sum replace

tabout wageDens using mwagemass.csv if mwage==7.25, cell(max wageDens) f(5c) style(csv) sum oneway replace

tabout if mwage>=7.25 & mwage<=30.5 using WageDistParams.csv, cell(mean lnmwage sd) f(5c) style(csv) sum oneway replace

estpost summarize lnmwage if mwage>=7.25 & mwage<=30.5
esttab using WageDistParams.csv, noobs cells("mean sd") replace
